;; lib.scm
;; Copyright (C) 2017-2018 Michael Rosset <mike.rosset@gmail.com>

;; This file is part of Nomad

;; Nomad is free software: you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the
;; Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; Nomad is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
;; See the GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License along
;; with this program.  If not, see <http://www.gnu.org/licenses/>.

(define-module (nomad lib)
  #:export (dynamic-path))

;; FIXE: catch the right exception here
(catch #t
  (lambda _
    (load-extension "libguile-nomad" "init_guile_nomad_lib"))
  (lambda (key . param)
    (load-extension "/usr/local/libexec/nomad/libguile-nomad.so"
                    "init_guile_nomad_lib")))

(define (dynamic-path)
  (if (libguile-nomad?)
      "libguile-nomad"
      "/usr/local/libexec/nomad/libguile-nomad.so"))

;; Local Variables:
;; mode: scheme
;; End:
